@@ -1,7 +1,7 @@
 from typing import Callable
 from MarkLib.taskstage import TaskStage
 from MarkLib.taskitem import TaskItem
-from MarkLib.models.condition import Condition
+from .models.condition import Condition
 
 
 class Task:
